---
name: Problem report
about: Create a problem report
title: ''
labels: ''
assignees: ''

---

**Describe the problem:**

Please provide a clear and detailed description of what the problem is.

**To Reproduce:**

The version of Plaso you used:

For example: 20171231

The operating system you are running Plaso on (Not the operating system of the image/files you're trying to analyze):

For example: Ubuntu 22.04

Steps to reproduce the behavior including command line and arguments and output:

First I ran `log2timeline.py --help` that provided me the following output `...`

Please provide the source data you used when you experienced the problem. For publicly available data please provide a URL or path of the source data.

For example: individual ChromeOS syslog file

The method you used to install Plaso:

For example:
* installed from [GiFT PPA][https://launchpad.net/~gift] stable track
* installed from [GiFT COPR][https://copr.fedorainfracloud.org/coprs/g/gift/] stable track
* installed from [l2tbinaries][https://github.com/log2timeline/l2tbinaries] main branch
* built using [l2devtools][https://github.com/log2timeline/l2tdevtools]
* other, namely ...

If multiple installation methods were used please indicate.

**Expected behavior:**

A clear and concise description of what you expected to happen.

**Debug output/tracebacks:**

You can run log2timeline tools with "-d" to generate debug output, and include anything relevant. Also see: [Producing debug logs][https://plaso.readthedocs.io/en/latest/sources/Troubleshooting.html#producing-debug-logs]

Please DO NOT provide screenshots, they can be hard to read.

For more information see the [troubleshooting guide][https://plaso.readthedocs.io/en/latest/sources/Troubleshooting.html]

**Additional context**

Any other context about the problem here.
